@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-ur'''\
+u'''\
 
 :mod:`ecoxipy.decorators` - Decorators for Shorter XML-Creation Code
 ====================================================================
@@ -31,10 +31,10 @@ available and a list of allowed element names:
 ...         _b('<raw/>text'),
 ...         _b(br, (str(i) for i in range(3))),
 ...         (str(i) for i in range(3, 6)),
-...         attr='\'"<&>'
+...         attr='\\'"<&>'
 ...     )
 ...
->>> view('Hello World!') == u"""<section attr="'&quot;&lt;&amp;&gt;"><p>Hello World!</p><p>äöüß</p><p>&lt;&amp;&gt;</p><raw/>text<br/>012345</section>""".encode('utf-8')
+>>> view('Hello World!') == u"""<section attr="'&quot;&lt;&amp;&gt;"><p>Hello World!</p><p>äöüß</p><p>&lt;&amp;&gt;</p><raw/>text<br/>012345</section>"""
 True
 
 
@@ -52,15 +52,15 @@ using :class:`ecoxipy.string_output.StringOutput` as the
 ...         p('<&>'),
 ...         _b('<raw/>text', br, (str(i) for i in range(3))),
 ...         (str(i) for i in range(3, 6)),
-...         attr='\'"<&>'
+...         attr='\\'"<&>'
 ...     )
 ...
->>> view('Hello World!') == u"""<section attr="'&quot;&lt;&amp;&gt;"><p>Hello World!</p><p>äöüß</p><p>&lt;&amp;&gt;</p><raw/>text<br/>012345</section>""".encode('utf-8')
+>>> view('Hello World!') == u"""<section attr="'&quot;&lt;&amp;&gt;"><p>Hello World!</p><p>äöüß</p><p>&lt;&amp;&gt;</p><raw/>text<br/>012345</section>"""
 True
 
 
-To create UTF-8 encoded `HTML5 <http://www.w3.org/TR/html5/>`_ strings
-use the :func:`html5` decorator:
+To create `HTML5 <http://www.w3.org/TR/html5/>`_ XML strings use the
+:func:`html5` decorator:
 
 >>> @html5
 ... def page(page_title, page_content):
@@ -74,8 +74,8 @@ use the :func:`html5` decorator:
 ...             _b('<footer>Copyright</footer>')
 ...         ),
 ...     )
->>> print page('Test', 'Hello World & Universe!')
-<html><head><title>Test</title></head><body><h1>Test</h1><p>Hello World &amp; Universe!</p><footer>Copyright</footer></body></html>
+>>> page('Test', 'Hello World & Universe!') == u'<html><head><title>Test</title></head><body><h1>Test</h1><p>Hello World &amp; Universe!</p><footer>Copyright</footer></body></html>'
+True
 
 
 Decorator Creation
@@ -107,16 +107,22 @@ HTML5
     <http://www.w3.org/TR/html5/semantics.html#semantics>`_. Each set contains
     for each element contained in the respective category a :func:`str` equal
     to the element's name.
+
+.. py:data:: HTML5_ELEMENT_NAMES
+
+    An :func:`frozenset` of all HTML5 element names as defined in
+    :data:`HTML5_ELEMENTS`.
+
 '''
 
 import tinkerpy
 
-import ecoxipy
-import string_output
+from ecoxipy import MarkupBuilder
+from ecoxipy.string_output import StringOutput
 
 
 def markup_builder_namespace(output, builder_name, *element_names, **kargs):
-    ur'''\
+    '''\
     A function creating a :func:`tinkerpy.namespace` decorator. It has all in
     ``element_names`` defined names bound to the appropriate `virtual` methods
     of a new :class:`ecoxipy.MarkupBuilder` instance, which uses a new
@@ -132,7 +138,7 @@ def markup_builder_namespace(output, builder_name, *element_names, **kargs):
     :returns: The decorated function with it's namespace extented by the
         element creators, as defined by ``element_names``.
     '''
-    builder = ecoxipy.MarkupBuilder(output(**kargs))
+    builder = MarkupBuilder(output(**kargs))
     return tinkerpy.namespace(builder,
         *element_names,
         **{builder_name: builder}
@@ -140,8 +146,8 @@ def markup_builder_namespace(output, builder_name, *element_names, **kargs):
 
 
 xml_string_namespace = lambda builder_name, vocabulary: markup_builder_namespace(
-        string_output.StringOutput, builder_name, *tinkerpy.flatten(vocabulary))
-ur'''\
+        StringOutput, builder_name, *vocabulary)
+'''\
 Uses :func:`markup_builder_namespace` to decorate the target
 function with the given ``vocabulary``.
 
@@ -185,9 +191,9 @@ def HTML5_ELEMENTS():
 
 
 HTML5_ELEMENTS = HTML5_ELEMENTS()
-
+HTML5_ELEMENT_NAMES = frozenset(tinkerpy.flatten(HTML5_ELEMENTS))
 
 def html5():
-    return xml_string_namespace('_b', HTML5_ELEMENTS)
+    return xml_string_namespace('_b', HTML5_ELEMENT_NAMES)
 
 html5 = html5()
